@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: Comment.php,v 1.21.2.1 2006/03/27 15:31:26 jenst Exp $
+ * $Id: Comment.php 13504 2006-04-22 21:09:30Z jenst $
  */
 ?>
 <?php
@@ -57,7 +57,7 @@ class Comment {
 		$name = '';
 		$user = $gallery->userDB->getUserByUid($this->UID);
 		
-		if  ($gallery->app->comments_anonymous == 'no') {
+		if (!$user->isPseudo()) {
 		    $name = $user->printableName($gallery->app->comments_display_name);
 		}
 		
