@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: do_command.php,v 1.89.2.1 2006/03/27 15:31:25 jenst Exp $
+ * $Id: do_command.php 13848 2006-06-19 12:04:01Z jenst $
  */
 ?>
 <?php
@@ -130,7 +130,7 @@ switch ($cmd) {
 	break;
 	
 	case 'logout':
-		gallery_syslog("Logout by ". $gallery->session->username ." from ". $HTTP_SERVER_VARS['REMOTE_ADDR']);
+		gallery_syslog("Logout by ". $gallery->session->username ." from ". $_SERVER['REMOTE_ADDR']);
 		$gallery->session->username = '';
 		$gallery->session->language = '';
 		destroyGallerySession();
