@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: edit_appearance.php,v 1.117.2.1 2006/03/27 15:31:25 jenst Exp $
+ * $Id: edit_appearance.php 14310 2006-08-14 07:41:08Z jenst $
  */
 ?>
 <?php
@@ -237,15 +237,15 @@ doctype();
 <div class="popuphead"><?php echo gTranslate('core', "Album Properties") ?></div>
 <?php echo infoLine($infoMessages, 'error'); ?>
 <div class="popup" align="center">
-<?php 
-
-echo makeFormIntro("edit_appearance.php",
-    array("name" => "theform"),
-    array("type" => "popup"));
+<?php
 
 $i = 0;
+$initialtab = makeSectionTabs($properties, $initialtab, true);
 
-makeSectionTabs($properties,5, $initialtab, true);
+echo "<div style=\"clear: both\"></div>";
+echo makeFormIntro('edit_appearance.php',
+    array("name" => "theform"),
+    array('type' => 'popup', 'initialtab' => $initialtab));
 
 foreach ($properties as $key => $val) {
     if(!empty($val['skip'])) {
@@ -258,7 +258,7 @@ foreach ($properties as $key => $val) {
         } else {
             $display = 'none';
         }
-        echo "\n<div id=\"". $val["name"] ."\" style=\"display: $display\">";
+        echo "\n<div id=\"{$val["name"]}\" style=\"display: $display\">";
         echo make_separator($key, $val);
         echo "\n<table width=\"100%\" class=\"inner\">";
         continue;
