@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: init.php,v 1.55.2.1 2006/03/27 15:32:13 jenst Exp $
+ * $Id: init.php 13957 2006-07-12 11:48:20Z jenst $
  */
 ?>
 <?php
@@ -31,7 +31,8 @@ if (stristr (__FILE__, '/var/lib/gallery/setup')) {
 
 /* define the constants */
 setGalleryPaths();
-if (!isset($gallery->app->photoAlbumURL)) {
+
+if (!isset($gallery) || !isset($gallery->app->photoAlbumURL)) {
     define ('GALLERY_URL','..');
 }
 
